HGH for Hydrogren (H) in PBE ,generated by Saha,2015
    1    1  20150309 zatom, zion, date (yymmdd)
   10   -101130 -1 0 2002 0   pspcod, ixc, lmax, lloc, mmax, r2well
    0.228727444559 2 -3.722900963668  0.657596429179 rloc nloc c1 .. cnloc
     0                                                       nsep
